'''
Advanced Power Battery Wraper Dummy
2009-2010(c) Kirill Plyashkevich <ru.spirit@gmail.com>
'''

from wrappers.battery.AbstractBattery import AbstractBattery

class BatteryDummy(AbstractBattery):

  def pre_init(self):
    self.friendly_name = 'Dummy'
    self.depends['packages'] = {'advanced-power-monitor': '0.5.1'}
    self.interfaces_map = {}
    self.export_signals = {'battery_charger_is_connected': {},
                           'battery_charger_is_disconnected': {},
                           'battery_is_full': {},
                           'battery_percentage': {},
                           'battery_timeleft_info': {}
                          }

  def post_init(self):
    pass

  def get_percent(self, value, props):
    return 'unknown'

  def update_percnet(self):
    return 'unknown'

  def get_status(self):
    pass

  def get_timeleft(self):
    return [self.timeleft_idle, self.timeleft_active]

  def update_timeleft(self):
    return [self.timeleft_idle, self.timeleft_active]
